@@ -174,21 +174,7 @@ package inc::MBX::Alien::FLTK::Base;
         );
         $self->notes('include_dirs' => {});
         $self->notes('lib_dirs'     => {});
-        {
-            print 'Locating library archiver... ';
-            open(my ($OLDOUT), ">&STDOUT");
-            close *STDOUT;
-            my ($ar) = grep { run("$_ V") } can_run($Config{'ar'});
-            open(*STDOUT, '>&', $OLDOUT)
-                || exit !print "Couldn't restore STDOUT: $!\n";
-            if (!$ar) {
-                print "Could not find the library archiver, aborting.\n";
-                exit 0;
-            }
-            $ar .= ' cr' . (can_run($Config{'ranlib'}) ? 's' : '');
-            $self->notes(AR => $ar);
-            print "$ar\n";
-        }
+        $self->_configure_ar;
         {
             my %sizeof;
             for my $type (qw[short int long]) {
@@ -287,7 +273,7 @@ int main ( ) {
                 my $print = '';
                 for my $key (@defines) {
                     $print
-                        .= '#ifdef ' 
+                        .= '#ifdef '
                         . $key . "\n"
                         . '    printf("'
                         . $key
@@ -554,9 +540,9 @@ int main ( ) {
 }
 
                 my $define = uc 'HAVE_' . $header;
+                $define =~ s|[/\.]|_|g;
                 if ($exe) {
                     print "    yes ($header)\n";
-                    $define =~ s|[/\.]|_|g;
                     $self->notes('define')->{$define} = 1;
 
                     #$self->notes('cache')->{'header_dirent'} = $header;
@@ -684,6 +670,23 @@ int main () {
         return 1;
     }
 
+    sub _configure_ar {
+        my $s = shift;
+        print 'Locating library archiver... ';
+        open(my ($OLDOUT), ">&STDOUT");
+        close *STDOUT;
+        my ($ar) = grep { run("$_ V") } can_run($Config{'ar'});
+        open(*STDOUT, '>&', $OLDOUT)
+            || exit !print "Couldn't restore STDOUT: $!\n";
+        if (!$ar) {
+            print "Could not find the library archiver, aborting.\n";
+            exit 0;
+        }
+        $ar .= ' cr' . (can_run($Config{'ranlib'}) ? 's' : '');
+        $s->notes(AR => $ar);
+        print "$ar\n";
+    }
+
     sub build_fltk {
         my ($self, $build) = @_;
         $self->quiet(1);
